@@ -221,7 +221,7 @@ class Target:
 
     def __call__(self, command, **kw):
         ret, out, err = self.run(command, **kw)
-        print('\n'.join([f'\n >{self.host}> {command}\n']+out))
+        print('\n'.join(out))
         return ret
 
     def rsync(self, *arg, **kw):
